@@ -43,6 +43,7 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDebug>
+#include <QtQuickControls2/QQuickStyle>
 
 #include <kiconengine.h>
 #include <kiconloader.h>
@@ -96,6 +97,7 @@ KdePlatformTheme::KdePlatformTheme()
 #endif
 
     QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar, false);
+    setQtQuickControlsTheme();
 }
 
 KdePlatformTheme::~KdePlatformTheme()
@@ -390,4 +392,22 @@ QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
 }
 #endif
 
+//force QtQuickControls2 to use the desktop theme as default
+void KdePlatformTheme::setQtQuickControlsTheme()
+{
+    //if the user is running only a QGuiApplication, explicitely unset the QQC1 desktop style and abort
+    //as this style is all about QWidgets and we know setting this will make it crash
+    if (!qobject_cast<QApplication*>(qApp)) {
+        if (qgetenv("QT_QUICK_CONTROLS_1_STYLE").right(7) == "Desktop") {
+            qunsetenv("QT_QUICK_CONTROLS_1_STYLE");
+        }
+        return;
+    }
+    //if the user has explicitly set something else, don't meddle
+    if (!QQuickStyle::name().isEmpty()) {
+        return;
+    }
+    QQuickStyle::setStyle(QLatin1String("org.kde.desktop"));
+}
+
 #include "kdeplatformtheme.moc"
